﻿using AutoWorkshopContracts.BindingModels;
using AutoWorkshopContracts.BusinessLogicsContracts;
using AutoWorkshopContracts.ViewModels;
using Microsoft.Extensions.Logging;

namespace AutoWorkshopView.Forms.Shop
{
    public partial class FormCreateSupply : Form
    {
        private readonly ILogger _logger;
        private readonly IRepairLogic _logicP;
        private readonly IShopLogic _logicS;
        
        private List<ShopViewModel> _shopList = new List<ShopViewModel>();
        private List<RepairViewModel> _RepairList = new List<RepairViewModel>();

        public FormCreateSupply(ILogger<FormCreateSupply> logger, IRepairLogic logicP, IShopLogic logicS)
        {
            InitializeComponent();
            _logger = logger;
            _logicP = logicP;
            _logicS = logicS;
        }

        private void FormCreateSupply_Load(object sender, EventArgs e)
        {
            _shopList = _logicS.ReadList(null);
            _RepairList = _logicP.ReadList(null);
            if (_shopList != null)
            {
                comboBoxShop.DisplayMember = "ShopName";
                comboBoxShop.ValueMember = "Id";
                comboBoxShop.DataSource = _shopList;
                comboBoxShop.SelectedItem = null;
                _logger.LogInformation("Загрузка магазинов для поставок");
            }
            if (_RepairList != null)
            {
                comboBoxRepair.DisplayMember = "RepairName";
                comboBoxRepair.ValueMember = "Id";
                comboBoxRepair.DataSource = _RepairList;
                comboBoxRepair.SelectedItem = null;
                _logger.LogInformation("Загрузка ремонтов для поставок");
            }
        }

        private void ButtonSave_Click(object sender, EventArgs e)
        {
            if (comboBoxShop.SelectedValue == null)
            {
                MessageBox.Show("Выберите магазин", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (comboBoxRepair.SelectedValue == null)
            {
                MessageBox.Show("Выберите изделие", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Создание поставки");
            try
            {
                var operationResult = _logicS.MakeSupply(new SupplyBindingModel
                {
                    ShopId = Convert.ToInt32(comboBoxShop.SelectedValue),
                    RepairId = Convert.ToInt32(comboBoxRepair.SelectedValue),
                    Count = Convert.ToInt32(textBoxCount.Text)
                });
                if (!operationResult)
                {
                    throw new Exception("Ошибка при создании поставки. Дополнительная информация в логах.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка создания поставки");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }
    }
}
